@@ -1,4 +1,4 @@
--- $Id: stored.sql 42198 2014-09-10 13:24:54Z wsl $
+-- $Id: stored.sql 42714 2014-12-19 14:39:27Z wsl $
 -- $URL: https://svn.uvt.nl/its-id/trunk/sources/kiki/doc/stored.sql $
 
 \encoding UTF8
@@ -77,6 +77,26 @@ CREATE OR REPLACE FUNCTION create_domain(IN v TEXT, OUT d BIGINT) AS $$
 			INSERT INTO domainnames (domain, name) VALUES (d, m)
 				RETURNING domainname INTO n;
 			INSERT INTO domains (domain, main) VALUES (d, n);
+
+			INSERT INTO mail_aliases (name, domain, addressbook)
+				VALUES ('postmaster', d, FALSE)
+				RETURNING mail_alias INTO a;
+			PERFORM create_destination(a, 'postmaster@uvt.nl');
+
+			INSERT INTO mail_aliases (name, domain, addressbook)
+				VALUES ('hostmaster', d, FALSE)
+				RETURNING mail_alias INTO a;
+			PERFORM create_destination(a, 'hostmaster@uvt.nl');
+
+			INSERT INTO mail_aliases (name, domain, addressbook)
+				VALUES ('webmaster', d, FALSE)
+				RETURNING mail_alias INTO a;
+			PERFORM create_destination(a, 'webmaster@uvt.nl');
+
+			INSERT INTO mail_aliases (name, domain, addressbook)
+				VALUES ('abuse', d, FALSE)
+				RETURNING mail_alias INTO a;
+			PERFORM create_destination(a, 'abuse@uvt.nl');
 		END IF;
 	END;
 $$ LANGUAGE plpgsql;
@@ -109,6 +129,24 @@ CREATE OR REPLACE FUNCTION alias2person(u TEXT) RETURNS BIGINT AS $$
 	END;
 $$ LANGUAGE plpgsql;
 
+CREATE OR REPLACE FUNCTION create_single_alias(isrc TEXT, idst TEXT) RETURNS VOID AS $$
+	DECLARE
+		l TEXT;
+		r TEXT;
+		d BIGINT;
+		a BIGINT;
+	BEGIN
+		l = split_part(isrc, '@', 1);
+		r = lower(split_part(isrc, '@', 2));
+		d := name2domain(r);
+
+		INSERT INTO mail_aliases (name, domain, addressbook)
+			VALUES (l, d, FALSE)
+			RETURNING mail_alias INTO a;
+		PERFORM create_destination(a, idst);
+	END;
+$$ LANGUAGE plpgsql;
+
 CREATE OR REPLACE FUNCTION create_destination(ialias BIGINT, imail TEXT) RETURNS VOID AS $$
 	DECLARE
 		l TEXT;
